Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(56)

Unified Diff: base/sequence_checker.h

Issue 2189113002: Rename CalledOnValidSequencedThread() to CalledOnValidSequence(). (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/memory/weak_ptr.cc ('k') | base/sequence_checker_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/sequence_checker.h
diff --git a/base/sequence_checker.h b/base/sequence_checker.h
index b23941cdadf67594d09b1b9e988744507ac4cb68..bb7b346acf36d3049f34c3269d45c66b972fcdd2 100644
--- a/base/sequence_checker.h
+++ b/base/sequence_checker.h
@@ -22,9 +22,7 @@ namespace base {
// the right version for your build configuration.
class SequenceCheckerDoNothing {
public:
- bool CalledOnValidSequencedThread() const {
- return true;
- }
+ bool CalledOnValidSequence() const { return true; }
void DetachFromSequence() {}
};
@@ -39,7 +37,7 @@ class SequenceCheckerDoNothing {
// class MyClass {
// public:
// void Foo() {
-// DCHECK(sequence_checker_.CalledOnValidSequencedThread());
+// DCHECK(sequence_checker_.CalledOnValidSequence());
// ... (do stuff) ...
// }
//
@@ -47,7 +45,7 @@ class SequenceCheckerDoNothing {
// SequenceChecker sequence_checker_;
// }
//
// In Release mode, CalledOnValidSequencedThread() will always return true.
#if ENABLE_SEQUENCE_CHECKER
class SequenceChecker : public SequenceCheckerImpl {
};
@@ -47,7 +45,7 @@ class SequenceCheckerDoNothing {
// }
//
-// In Release mode, CalledOnValidSequencedThread() will always return true.
+// In Release mode, CalledOnValidSequence() will always return true.
#if ENABLE_SEQUENCE_CHECKER
class SequenceChecker : public SequenceCheckerImpl {
« no previous file with comments | « base/memory/weak_ptr.cc ('k') | base/sequence_checker_impl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698